summaryrefslogtreecommitdiff
path: root/dns
diff options
context:
space:
mode:
authorBob Halley <halley@dnspython.org>2012-05-21 18:34:46 +0100
committerBob Halley <halley@dnspython.org>2012-05-21 18:34:46 +0100
commitd65a7a8f7d23c3d4219364069bdd41f19c8215f9 (patch)
tree14d83f8a35aa419de7b25e743064c515751c9569 /dns
parent7702ddde24a57bfa292fda2131b5037c7fce6d0a (diff)
downloaddnspython-d65a7a8f7d23c3d4219364069bdd41f19c8215f9.tar.gz
fix typos
Diffstat (limited to 'dns')
-rw-r--r--dns/edns.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/dns/edns.py b/dns/edns.py
index 4d4eaa8..e52b6df 100644
--- a/dns/edns.py
+++ b/dns/edns.py
@@ -44,13 +44,13 @@ class Option(object):
@type current: int
@param olen: The length of the wire-format option data
@type olen: int
- @rtype: dns.ends.Option instance"""
+ @rtype: dns.edns.Option instance"""
raise NotImplementedError
from_wire = classmethod(from_wire)
def _cmp(self, other):
"""Compare an ENDS option with another option of the same type.
Return < 0 if self < other, 0 if self == other, and > 0 if self > other.
"""
raise NotImplementedError
@@ -136,7 +136,7 @@ def option_from_wire(otype, wire, current, olen):
@type current: int
@param olen: The length of the wire-format option data
@type olen: int
- @rtype: dns.ends.Option instance"""
+ @rtype: dns.edns.Option instance"""
cls = get_option_class(otype)
return cls.from_wire(otype, wire, current, olen)
@@ -44,13 +44,13 @@ class Option(object):
from_wire = classmethod(from_wire)
def _cmp(self, other):
- """Compare an ENDS option with another option of the same type.
+ """Compare an EDNS option with another option of the same type.
Return < 0 if self < other, 0 if self == other, and > 0 if self > other.
"""